@@ -19,7 +19,9 @@ import dtool_lookup_server.utils
 from dtool_lookup_server.utils import (
     base_uri_exists,
     user_exists,
+    delete_users,
     register_users,
+    update_users,
     register_base_uri,
     get_permission_info,
     update_permissions,
@@ -54,6 +56,37 @@ def register_user(username, is_admin):
     register_users(users)
 
 
+@user_cli.command(name="update")
+@click.argument('username')
+@click.option('-a', '--is_admin', is_flag=True)
+def update_user(username, is_admin):
+    """Update a user in the dtool lookup server."""
+
+    if not user_exists(username):
+        click.secho(
+            "User '{}' is not registered yet".format(username),
+            fg="red",
+            err=True
+        )
+        sys.exit(1)
+
+    users = [{
+        "username": username,
+        "is_admin": is_admin
+    }]
+    update_users(users)
+
+
+@user_cli.command(name="delete")
+@click.argument('username')
+def delete_user(username):
+    """Delete a user in the dtool lookup server."""
+    users = [{
+        "username": username,
+    }]
+    delete_users(users)
+
+
 @user_cli.command(name="list")
 def list_users():
     """List the users in the dtool lookup server."""
